<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="gl_ES">
<context>
    <name>API</name>
    <message>
        <source>Please log in with your Deepin ID.</source>
        <translation>Inicia sesión co teu Usuario Deepin.</translation>
    </message>
    <message>
        <source>You need to log in to proceed with the subsequent operations.</source>
        <translation>Debe iniciar sesión para continuar coas operacións posteriores.</translation>
    </message>
</context>
<context>
    <name>APIProxy</name>
    <message>
        <source>You have been making too many requests, Please try again later.</source>
        <translation>Estiveches facendo demasiadas solicitudes. Téntao de novo máis tarde.</translation>
    </message>
    <message>
        <source>You need to login to proceed with the subsequent operations.</source>
        <translation>Debe iniciar sesión para continuar coas operacións posteriores.</translation>
    </message>
    <message>
        <source>Network error, please try later.</source>
        <translation>Erro de rede, ténteo máis tarde.</translation>
    </message>
</context>
<context>
    <name>AccountButton</name>
    <message>
        <source>Unlogged</source>
        <translation>Desconectado</translation>
    </message>
    <message>
        <source>My Favorites</source>
        <translation>Os meus favoritos</translation>
    </message>
    <message>
        <source>My Feedbacks</source>
        <translation>Os meus comentarios</translation>
    </message>
    <message>
        <source>Sign out</source>
        <translation>Pechar sesión</translation>
    </message>
    <message>
        <source>Sign in</source>
        <translation>Inicia sesión</translation>
    </message>
</context>
<context>
    <name>Card</name>
    <message>
        <source>%1 views</source>
        <translation>%1 vistas</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Suxestións</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Non favoritos</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorito</translation>
    </message>
    <message>
        <source>Cancel the urge</source>
        <translation>Cancelar a urxencia</translation>
    </message>
    <message>
        <source>Urge</source>
        <translation>Urxir</translation>
    </message>
</context>
<context>
    <name>Card1</name>
    <message>
        <source>Coming</source>
        <translation>Chegando</translation>
    </message>
</context>
<context>
    <name>Detail</name>
    <message>
        <source>Official response</source>
        <translation>Resposta oficial</translation>
    </message>
</context>
<context>
    <name>Filter</name>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Introducir:</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Todo</translation>
    </message>
    <message>
        <source>Bug</source>
        <translation>Erro</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Suxestións</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Versión:</translation>
    </message>
    <message>
        <source>Sort:</source>
        <translation>Ordenar:</translation>
    </message>
    <message>
        <source>Newest</source>
        <translation>O máis novo</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorito</translation>
    </message>
    <message>
        <source>Urge</source>
        <translation>Urxir</translation>
    </message>
</context>
<context>
    <name>Index</name>
    <message>
        <source>Communication</source>
        <translation>Comunicación</translation>
    </message>
    <message>
        <source>Discuss and share here</source>
        <translation>Comenta e comparte aquí</translation>
    </message>
    <message>
        <source>Bug Report</source>
        <translation>Reporte de erros</translation>
    </message>
    <message>
        <source>Report issues you found</source>
        <translation>Informa dos problemas que atopaches</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Suxestións</translation>
    </message>
    <message>
        <source>Submit your suggestions</source>
        <translation>Aportar as túas suxestións</translation>
    </message>
    <message>
        <source>Resources</source>
        <translation>Recursos</translation>
    </message>
    <message>
        <source>Questionaire</source>
        <translation>Cuestionario</translation>
    </message>
    <message>
        <source>Join US</source>
        <translation>Únete a nós</translation>
    </message>
    <message>
        <source>Internal Testing</source>
        <translation>Probas internas</translation>
    </message>
    <message>
        <source>Global Translation</source>
        <translation>Xente de tradución global</translation>
    </message>
    <message>
        <source>Community News</source>
        <translation>Novas da comunidade</translation>
    </message>
</context>
<context>
    <name>List</name>
    <message>
        <source>No more items</source>
        <translation>Non hai máis elementos</translation>
    </message>
    <message>
        <source>Messages</source>
        <translation>Mensaxe</translation>
    </message>
    <message>
        <source>Questionaires</source>
        <translation>Cuestionarios</translation>
    </message>
</context>
<context>
    <name>MyTitleBar</name>
    <message>
        <source>Launch at system startup</source>
        <translation>Iniciar ao inicio do sistema</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Saír</translation>
    </message>
    <message>
        <source>Deepin Home</source>
        <translation>Deepin Home</translation>
    </message>
    <message>
        <source>Quick login to forums, submit suggestions, and report bugs.</source>
        <translation>Inicio de sesión rápido en foros, enviar suxestións e informar erros.</translation>
    </message>
</context>
<context>
    <name>Notify</name>
    <message>
        <source>No messages yet.</source>
        <translation>Aínda non hai mensaxes.</translation>
    </message>
    <message>
        <source>%1 messages</source>
        <translation>%1 mensaxes</translation>
    </message>
    <message>
        <source>Mark all as read</source>
        <translation>Marcar todos como lidos</translation>
    </message>
</context>
<context>
    <name>NotifyDetail</name>
    <message>
        <source>View more</source>
        <translation>Ver máis</translation>
    </message>
</context>
<context>
    <name>Offline</name>
    <message>
        <source>Network error, please try later</source>
        <translation>Erro de rede, téntao máis tarde</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Actualizar</translation>
    </message>
</context>
<context>
    <name>Preload</name>
    <message>
        <source>Deepin Home</source>
        <translation>Deepin Home</translation>
    </message>
</context>
<context>
    <name>Questionnaire</name>
    <message>
        <source>No questionaires yet.</source>
        <translation>Aínda non hai cuestionarios</translation>
    </message>
    <message>
        <source>Expired on: %1</source>
        <translation>Caducou o: %1</translation>
    </message>
    <message>
        <source>Fill In</source>
        <translation>Encher</translation>
    </message>
</context>
<context>
    <name>Status</name>
    <message>
        <source>Pending</source>
        <translation>Pendente</translation>
    </message>
    <message>
        <source>Reproducing</source>
        <translation>Reproducindo</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Confirmado</translation>
    </message>
    <message>
        <source>Replied</source>
        <translation>Respondido</translation>
    </message>
    <message>
        <source>Resolved</source>
        <translation>Resolto</translation>
    </message>
    <message>
        <source>Evaluating</source>
        <translation>Avaliando</translation>
    </message>
    <message>
        <source>Accepted</source>
        <translation>Aceptado</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Completado</translation>
    </message>
    <message>
        <source>The issue has not been processed and will not be displayed in the public listing.</source>
        <translation>O problema non foi procesado e non se mostrará na lista pública.</translation>
    </message>
    <message>
        <source>Currently unable to identify the cause; continuous monitoring and investigation are required.</source>
        <translation>Actualmente non se pode identificar a causa; é necesario un seguimento e investigación continuados.</translation>
    </message>
    <message>
        <source>The issue has been reproduced and the root cause has been identified.</source>
        <translation>O problema reproduciuse e identificouse a causa raíz.</translation>
    </message>
    <message>
        <source>The issue is not a bug or of a different nature.</source>
        <translation>O problema non é un erro ou de natureza diferente.</translation>
    </message>
    <message>
        <source>The issue has been resolved and awaiting formal release</source>
        <translation>O problema resolveuse e está á espera da liberación formal</translation>
    </message>
    <message>
        <source>The requirement has not been processed and will not be displayed in the public listing</source>
        <translation>O requisito non foi procesado e non se mostrará na listaxe pública</translation>
    </message>
    <message>
        <source>The issue has been acknowledged and is being internally assessed</source>
        <translation>O problema foi recoñecido e está a ser avaliado internamente</translation>
    </message>
    <message>
        <source>Included in the plans for a future release</source>
        <translation>Incluído nos plans para unha futura versión</translation>
    </message>
    <message>
        <source>The requirement is either not accepted or unable to be addressed</source>
        <translation>O requisito non se acepta ou non se pode atender</translation>
    </message>
    <message>
        <source>Development work is finished, awaiting formal release</source>
        <translation>O traballo de desenvolvemento está rematado, á espera da liberación formal</translation>
    </message>
</context>
<context>
    <name>Submit</name>
    <message>
        <source>Unable to add a screenshot.</source>
        <translation>Non se pode engadir unha captura de pantalla.</translation>
    </message>
    <message>
        <source>The image file size should be less than 1MB.</source>
        <translation>O tamaño do ficheiro de imaxe debe ser inferior a 1 MB.</translation>
    </message>
    <message>
        <source>The image file format is not supported for uploading.</source>
        <translation>O formato de ficheiro de imaxe non é compatible para a carga.</translation>
    </message>
    <message>
        <source>[Current Status of the Product]: 
[Desired Product]: </source>
        <translation>[Estado actual do produto]:
[Produto desexado]:</translation>
    </message>
    <message>
        <source>[Preconditions]: 
[Reproducibility Steps]: 
[Expected Results]: 
[Actual Results]: </source>
        <translation>[Condicións previas]:
[Pasos de reproducibilidade]:
[Resultados esperados]:
[Resultados reais]:</translation>
    </message>
    <message>
        <source>Submit Feedback</source>
        <translation>Enviar comentario</translation>
    </message>
    <message>
        <source>Type：</source>
        <translation>Introducir:</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Suxestións</translation>
    </message>
    <message>
        <source>Bug Report</source>
        <translation>Reporte de erros</translation>
    </message>
    <message>
        <source>Title：</source>
        <translation>Título:</translation>
    </message>
    <message>
        <source>Please provide a brief description of your issue</source>
        <translation>Proporcione unha breve descrición do seu problema</translation>
    </message>
    <message>
        <source>Content：</source>
        <translation>Contido:</translation>
    </message>
    <message>
        <source>Do not fill in multiple issues in one feedback</source>
        <translation>Non encha varios problemas nun só comentario</translation>
    </message>
    <message>
        <source>Do not fill in multiple requirements in one feedback</source>
        <translation>Non encha varios requisitos nun só comentario</translation>
    </message>
    <message>
        <source>Email：</source>
        <translation>Email:</translation>
    </message>
    <message>
        <source>Please enter your email</source>
        <translation>Por favor, introduza o seu email</translation>
    </message>
    <message>
        <source>System Version:</source>
        <translation>Versión do sistema:</translation>
    </message>
    <message>
        <source>Device Info：</source>
        <translation>Información do dispositivo:</translation>
    </message>
    <message>
        <source>Upload &lt;a href=&apos;home://sysinfo&apos;&gt;device information&lt;/a&gt;</source>
        <translation>Cargar &lt;a href=&apos;home://sysinfo&apos;&gt;información do sistema&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Screenshots：</source>
        <translation>Capturas de pantalla:</translation>
    </message>
    <message>
        <source>Image files</source>
        <translation>Arquivos de imaxe</translation>
    </message>
    <message>
        <source>Drag and drop files or click buttons to add pictures, up to three</source>
        <translation>Arrastra e solta ficheiros ou fai clic nos botóns para engadir imaxes, ata tres</translation>
    </message>
    <message>
        <source>Are you sure you want to exit the feedback submission?</source>
        <translation>Estás seguro de que queres saír do envío de comentarios?</translation>
    </message>
    <message>
        <source>The feedback content will not be saved.</source>
        <translation>Non se gardará o contido dos comentarios.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Saír</translation>
    </message>
    <message>
        <source>Submit</source>
        <translation>Enviar</translation>
    </message>
    <message>
        <source>Unable to submit feedback.</source>
        <translation>Non foi posíbel enviar o comentario.</translation>
    </message>
    <message>
        <source>Please provide the title and content of your feedback.</source>
        <translation>Proporcione o título e o contido do teu comentario.</translation>
    </message>
    <message>
        <source>Please provide the title of your feedback.</source>
        <translation>Introduza o título da teu comentario.</translation>
    </message>
    <message>
        <source>Please provide the content of your feedback.</source>
        <translation>Proporcione o contido dos teus comentarios.</translation>
    </message>
    <message>
        <source>Incorrect email address entered.</source>
        <translation>Dirección de email incorrecta.</translation>
    </message>
    <message>
        <source>Device Information</source>
        <translation>Información do dispositivo</translation>
    </message>
</context>
<context>
    <name>TabButton</name>
    <message>
        <source>Feedback Hub</source>
        <translation>Nodo de Comentarios</translation>
    </message>
    <message>
        <source>My Feedbacks</source>
        <translation>Os meus comentarios</translation>
    </message>
    <message>
        <source>My Favorites</source>
        <translation>Os meus favoritos</translation>
    </message>
    <message>
        <source>My Urged</source>
        <translation>Miñas Urxencias</translation>
    </message>
</context>
</TS>